<?PHP
#
#   FILE:  EditUserComplete.php
#
#   Part of the Collection Workflow Integration System (CWIS)
#   Copyright 2011-2015 Edward Almasy and Internet Scout Research Group
#   http://scout.wisc.edu/cwis/
#

# ----- LOCAL FUNCTIONS ------------------------------------------------------

/**
* Determine if the current user is editing his or her own account.
* @return Returns TRUE if the current user is editing his or her own account and
*      FALSE otherwise.
*/
function IsEditingOwnAccount()
{
    # user is logged in and is not SYSADMIN or USERADMIN
    if ((!$GLOBALS["G_User"]->HasPriv(PRIV_SYSADMIN) &&
        !$GLOBALS["G_User"]->HasPriv(PRIV_USERADMIN)) &&
        $GLOBALS["G_User"]->IsLoggedIn() == TRUE)
    {
        return TRUE;
    }
    else
    {
        return FALSE;
    }
}

# ----- MAIN -----------------------------------------------------------------

$F_DeleteSavedSearch = GetArrayValue($_POST, "F_DeleteSavedSearch");
$SubmitResult = GetArrayValue($_POST, "SubmitResult");

# make sure the user can view the page
if (!CheckAuthorization(PRIV_SYSADMIN, PRIV_USERADMIN))
{
    return;
}

# pull up record of user being edited
$UserToEdit = new CWUser(intval(GetArrayValue($_SESSION, "IdOfUserBeingEdited")));
unset($_SESSION["IdOfUserBeingEdited"]);

# if the user wasn't found
if ($UserToEdit->Status() !== U_OKAY)
{
    # go back to the user list
    $GLOBALS["AF"]->SetJumpToPage("UserList");
    return;
}

$UEUI = new UserEditingUI($UserToEdit);

# if submit button pushed
if ($SubmitResult == "Save Changes")
{
    # update the user information
    $UEUI->UpdateUserAttributes($_POST, FALSE, TRUE);
    $Errors = $UEUI->UpdateUserFields(CWUser::GetCustomUserFields());

    $UEUI->UploadImages($_POST, $_FILES);
    $UEUI->UploadFiles($_POST, $_FILES);

    # extract values from the form that need additional checks
    $F_NewPassword = GetArrayValue($_POST, "F_NewPassword");
    $F_Privileges = GetArrayValue($_POST, "F_Privileges", array());
    $F_UserDisabled = GetArrayValue($_POST, "F_UserDisabled", FALSE);
    $F_ActivateAccount = GetArrayValue($_POST, "F_ActivateAccount", FALSE);

    # change the user's password if necessary
    if (strlen($F_NewPassword))
    {
        $UserToEdit->SetPassword($F_NewPassword);
    }

    # don't allow non sysadmin to turn off sysadmin, user for a sysadmin
    if ($UserToEdit->HasPriv(PRIV_SYSADMIN)
        && $GLOBALS["G_User"]->HasPriv(PRIV_USERADMIN)
        && !$GLOBALS["G_User"]->HasPriv(PRIV_SYSADMIN))
    {
        $F_Privileges[] = PRIV_SYSADMIN;
        $F_Privileges[] = PRIV_USERADMIN;
    }

    # don't allow sysadmin turn off sysadmin, user for himself
    if ($UserToEdit->Get("UserId") == $GLOBALS["G_User"]->Get("UserId")
        && $GLOBALS["G_User"]->HasPriv(PRIV_SYSADMIN))
    {
        $F_Privileges[] = PRIV_SYSADMIN;
        $F_Privileges[] = PRIV_USERADMIN;
    }

    # if the new priv list differs from the old one
    # (per http://php.net/manual/en/language.operators.array.php,
    # arrays are == when they have the same key/value pairs
    # (regardless of order) and != when they do not. we'd only have to
    # worry about key ordering with a === or !== comparison)
    $OldPrivList = $UserToEdit->GetPrivList();
    if ($OldPrivList != $F_Privileges)
    {
        # update the user's privileges
        # (note: SetPrivList clears the list first, so it nukes PRIV_USERDISABLED)
        $UserToEdit->SetPrivList($F_Privileges);

        # signal that the user's privs were changed
        $GLOBALS["AF"]->SignalEvent(
            "EVENT_USER_PRIVILEGES_CHANGED", [
                "UserId" => $UserToEdit->Id(),
                "OldPrivileges" => $OldPrivList,
                "NewPrivileges" => $F_Privileges,
            ]);
    }

    # disable the user account if necessary, but don't allow users to disable
    # their own accounts
    if ($F_UserDisabled && $UserToEdit->Get("UserId")
            != $GLOBALS["G_User"]->Get("UserId"))
    {
        $UserToEdit->GrantPriv(PRIV_USERDISABLED);
    }

    # activate the user account if necessary
    if ($F_ActivateAccount)
    {
        # enable account for login
        $UserToEdit->RevokePriv(PRIV_USERDISABLED);
        $UserToEdit->IsActivated(TRUE);

        # signal that user has been activated
        $GLOBALS["AF"]->SignalEvent(
            "EVENT_USER_VERIFIED", array("UserId" => $UserToEdit->Id()));
    }

    # go back to the user list
    $GLOBALS["AF"]->SetJumpToPage("UserList");

    # update search and recommender DBs
    $UserToEdit->GetResource()->QueueSearchAndRecommenderUpdate();
}

# delete the user
else if ($SubmitResult == "Delete")
{
    # but first go to the confirmation page
    $_SESSION["UserRemoveArray"] = array($UserToEdit->Id());
    $GLOBALS["AF"]->SetJumpToPage("ConfirmRemoveUser");
}

# delete a saved search
else if (!is_null($F_DeleteSavedSearch))
{
    # update the user information
    $UEUI->UpdateUserAttributes($_POST);
    $Errors = $UEUI->UpdateUserFields(CWUser::GetCustomUserFields());

    $UEUI->UploadImages($_POST, $_FILES);
    $UEUI->UploadFiles($_POST, $_FILES);

    # delete the saved search
    $Search = new SavedSearch($F_DeleteSavedSearch);
    $Search->Delete();

    # return to the user editing page
    $AF->SetJumpToPage("EditUser&ID=".urlencode($UserToEdit->Id()));
}

else
{
    # return to front page
    $AF->SetJumpToPage("UserList");
}
